from setuptools import setup, find_packages

setup(name="mess_client_proj_2023",
      version="0.0.1",
      description="mess_client_proj_new",
      author="Vyacheslav Lashin",
      author_email="glory665@mail.ru",
      packages=find_packages(),
      install_requires=['PyQt5', 'sqlalchemy', 'pycryptodome', 'pycryptodomex']
      )
